@@ -1,5 +1,6 @@
 #include "mainwindow.h"
 #include "radio.h"
+#include "fontdialog.h"
 #include <QSettings>
 #include <QStringList>
 #include <QString>
@@ -11,11 +12,16 @@
 #include <QInputDialog>
 #include <QMessageBox>
 #include <QApplication>
+#include <QFontDialog>
+
+
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
 {
     w = new Radio();
+    b = new FontDialog(this);
+    connect(b, SIGNAL(saveButtonClicked(QFont,int)), this, SLOT(changeFont(QFont,int)));
 
     setCentralWidget(w);
 
@@ -23,12 +29,14 @@ MainWindow::MainWindow(QWidget *parent)
     createActions();
     createMenu();
     loadCurrentSet();
+    w->populateBox();
+    w->loadCurrentIndex();
 
 
 
     setWindowTitle("QRadio");
 
-    w->populateBox();
+
 }
 
 MainWindow::~MainWindow()
@@ -61,6 +69,8 @@ void MainWindow::createActions()
     connect(renameSetsAction, SIGNAL(triggered()), SLOT(renameSetsActionTriggered()));
     restartRadioAction = new QAction(tr("Restart Radio"), this);
     connect(restartRadioAction, SIGNAL(triggered()), w, SLOT(restartRadio()));
+    changeFontAction = new QAction("Change Font", this);
+    connect(changeFontAction, SIGNAL(triggered()), SLOT(changeFontActionTriggered()));
     aboutAction = new QAction("About", this); connect(aboutAction, SIGNAL(triggered()), SLOT(about()));
     aboutQtAction = new QAction("About Qt", this); connect(aboutQtAction, SIGNAL(triggered()), SLOT(aboutQt()));
 
@@ -91,14 +101,15 @@ void MainWindow::createMenu()
     menu->addAction(deleteStationAction);
     menu->addAction(manualAction);
     menu->addAction(renameSetsAction);
-    //menu->addAction(restartRadioAction);
+    menu->addAction(restartRadioAction);
+    menu->addAction(changeFontAction);
     menu->addAction(aboutAction);
     menu->addAction(aboutQtAction);
 }
 
 void MainWindow::addStationTriggered()
 {
-    int freq = w->currentFreq;
+    double freq = w->currentFreq;
 
     switch (currentSet)
     {
@@ -159,15 +170,22 @@ void MainWindow::set3ActionTriggered()
 
 void MainWindow::manualActionTriggered()
 {
-    int manualFreq = QInputDialog::getInt(this, tr("Manual Freq"), tr("Frequence"), 8750, 0, 13000, 10, 0, 0);
-    w->setFreq(manualFreq*10000);
+    bool ok;
+    double manualFreq = QInputDialog::getDouble(this, tr("Manual Freq"), tr("Frequence"), 87.50, 76.0, 108.0, 1, &ok, 0);
+    if (ok) w->setFreq(manualFreq*1000000);
 }
 
 void MainWindow::renameSetsActionTriggered()
 {
-    set1Name = QInputDialog::getText(this, "Sets Rename", "Insert Set1 Name:", QLineEdit::Normal, set1Name, 0 , 0);
-    set2Name = QInputDialog::getText(this, "Sets Rename", "Insert Set2 Name:", QLineEdit::Normal, set2Name, 0 , 0);
-    set3Name = QInputDialog::getText(this, "Sets Rename", "Insert Set3 Name:", QLineEdit::Normal, set3Name, 0 , 0);
+    bool ok1;
+    bool ok2;
+    bool ok3;
+    QString set1NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set1 Name:", QLineEdit::Normal, set1Name, &ok1 , 0);
+    QString set2NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set2 Name:", QLineEdit::Normal, set2Name, &ok2 , 0);
+    QString set3NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set3 Name:", QLineEdit::Normal, set3Name, &ok3 , 0);
+    if (ok1) set1Name = set1NameTemp;
+    if (ok2) set2Name = set2NameTemp;
+    if (ok3) set3Name = set3NameTemp;
     saveSetsName();
     set1Action->setText(set1Name);
     set2Action->setText(set2Name);
@@ -189,7 +207,7 @@ void MainWindow::deleteStationActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.0.3</h2>"
+                tr("<h2>QRadio 0.1.0</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
@@ -199,3 +217,16 @@ void MainWindow::aboutQt()
 {
     QApplication::aboutQt();
 }
+
+void MainWindow::changeFontActionTriggered()
+{
+    b->currentFont = w->getFontType();
+    b->currentFontSize = w->getFontSize();
+    b->setCurrent();
+    b->show();
+}
+
+void MainWindow::changeFont(QFont font, int n)
+{
+    w->changeFont(font, n);
+}
