@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include "radio.h"
+#include "fontdialog.h"
 
 class QAction;
 class QActionGroup;
@@ -22,6 +23,8 @@ private:
     void loadCurrentSet();
     void saveCurrentSet();
 
+    FontDialog *b;
+
     QAction *set1Action;
     QAction *set2Action;
     QAction *set3Action;
@@ -30,6 +33,7 @@ private:
     QAction *manualAction;
     QAction *renameSetsAction;
     QAction *restartRadioAction;
+    QAction *changeFontAction;
     QAction *aboutAction;
     QAction *aboutQtAction;
 
@@ -53,8 +57,10 @@ public slots:
     void manualActionTriggered();
     void renameSetsActionTriggered();
     void deleteStationActionTriggered();
+    void changeFontActionTriggered();
     void about();
     void aboutQt();
+    void changeFont(QFont, int);
 
 public:
     MainWindow(QWidget *parent = 0);
