@@ -12,6 +12,11 @@
 #include "clickableimage.h"
 #include <QSettings>
 #include <QTimer>
+#include <QFile>
+#include <QTextStream>
+#include <QApplication>
+
+
 
 void maemoBanner(QString string)
 {
@@ -34,13 +39,17 @@ Radio::Radio(QWidget *parent) :
     radio->setBand(QRadioTuner::FM);
 
     loadSetLists();
+    loadCurrentFont();
+    readRds();
+    restart=false;
 
 
-    radio->start();
+
+   // radio->start();
 
     QTimer *timer = new QTimer(this);
-    connect(timer, SIGNAL(timeout()), this, SLOT(restartRadio()));
-    timer->start(30000);
+    connect(timer, SIGNAL(timeout()), this, SLOT(readRds()));
+    timer->start(5000);
 
 
 
@@ -49,12 +58,23 @@ Radio::Radio(QWidget *parent) :
 void Radio::createUI()
 {
     stationName = new QLabel("Station Name");
-    freq = new QLCDNumber;
-    freq->setFixedHeight(280);
-    freq->setFixedWidth(450);
-    freq->setSmallDecimalPoint(true);
-    freq->setNumDigits(5);
-    freq->display(radio->frequency()/10000);
+    QFont stationFont;
+    stationFont.setUnderline(true);
+    stationFont.setBold(true);
+    stationName->setFont(stationFont);
+    rdsData = new QLabel("RDS Data");
+    QFont font;
+    font.setPointSize(14);
+    rdsData->setFont(font);
+
+    //QFont freqFont("Digital-7", 170);
+    freq = new QLabel;
+    //freq->setFont(freqFont);
+    freq->setFixedHeight(250);
+    freq->setFixedWidth(400);
+    //freq->setSmallDecimalPoint(false);
+    //freq->setNumDigits(5);
+    //freq->display(radio->frequency()/10000);
 
 
     signal = new QLabel;
@@ -113,6 +133,7 @@ void Radio::createUI()
     buttonLayout->addWidget(searchRight);
 
     mainLayout->addLayout(labelLayout);
+    mainLayout->addWidget(rdsData, 0, Qt::AlignLeft);
     mainLayout->addLayout(freqLayout);
     mainLayout->addLayout(buttonLayout);
 
@@ -154,11 +175,13 @@ void Radio::searchDown()
 
 void Radio::freqChanged(int)
     {
-        if (radio->frequency()/10000 < 10000)
-            freq->setNumDigits(4);
-        else freq->setNumDigits(5);
-        freq->display(radio->frequency()/10000);
-        currentFreq = radio->frequency()/10000;
+        //if (radio->frequency()/10000 < 10000)
+         //   freq->setNumDigits(4);
+      //  else freq->setNumDigits(5);
+
+      double freqI=radio->frequency()/1000000.0;
+      freq->setText(QString::number(freqI, 'f', 1));
+      currentFreq = radio->frequency()/1000000.0;
     }
 
     void Radio::signalChanged(int i)
@@ -173,11 +196,16 @@ void Radio::freqChanged(int)
             signal->setText(QString::number(i).append('%'));
     }
 
-    Radio::~Radio()
+Radio::~Radio()
     {
         saveSetLists();
         saveCurrentFreq();
-    }
+        saveCurrentIndex();
+
+
+
+
+}
 
 void Radio::metaDataChanged()
 {
@@ -215,7 +243,7 @@ void Radio::stationPicked(QString str)
 {
     int n;
     currentIndex = stationsBox->currentIndex();
-    n=str.toInt()*10000;
+    n=str.toDouble()*1000000;
     radio->setFrequency(n);
 }
 
@@ -242,14 +270,14 @@ void Radio::setFreq(int num)
 
 void Radio::loadCurrentFreq()
 {
-    QSettings settings("Maemo", "qradio");
-    currentFreq = settings.value("currentFreq", 8870).toInt();
+    /*QSettings settings("Maemo", "qradio");
+    currentFreq = settings.value("currentFreq", 8870).toInt();*/
 }
 
 void Radio::saveCurrentFreq()
 {
-    QSettings settings("Maemo", "qradio");
-    settings.setValue("currentFreq", currentFreq);
+    /*QSettings settings("Maemo", "qradio");
+    settings.setValue("currentFreq", currentFreq);*/
 }
 
 void Radio::nextButtonClicked()
@@ -266,6 +294,100 @@ void Radio::setLastIndex()
 
 void Radio::restartRadio()
 {
-    radio->stop();
-    radio->start();
+
+
+    maemoBanner("Radio restarting");
+
+    QApplication::exit();
+    restart=true;
+    QProcess *myProcess = new QProcess;
+    myProcess->execute("/opt/qradio/qradio");
+
+
+    //QTimer::singleShot(3000, radio, SLOT(start()));
+    //radio->start();
+}
+
+void Radio::readRds()
+{
+   // maemoBanner("read RDS");
+    QFile file("/sys/class/i2c-adapter/i2c-3/3-0022/rds_ps");
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
+      QString line;
+      QTextStream t( &file );
+      line = t.readLine();
+      stationName->setText(line);
+      file.close();
+      QFile file2("/sys/class/i2c-adapter/i2c-3/3-0022/rds_rt");
+      file2.open(QIODevice::ReadOnly | QIODevice::Text);
+
+        QTextStream t2( &file2 );
+        line = t2.readLine();
+        rdsData->setText(line);
+        file.close();
+
+
+}
+
+void Radio::saveCurrentIndex()
+{
+    QSettings settings("Maemo", "qradio");
+        settings.setValue("currentIndex", currentIndex);
+}
+
+void Radio::loadCurrentIndex()
+{
+    QSettings settings("Maemo", "qradio");
+        stationsBox->setCurrentIndex(settings.value("currentIndex").toInt());
+}
+
+QFont Radio::getFontType()
+{
+    QFont font = freq->font();
+    return font;
+
+}
+
+int Radio::getFontSize()
+{
+    return currentFontSize;
+}
+
+void Radio::changeFont(QFont font, int n)
+{
+    QFont freqFont(font.toString(), n);
+    freq->setFont(freqFont);
+    currentFontSize = n;
+    currentFont= font.toString();
+    saveCurrentFont();
+    QFont buttonFont(currentFont.toString(), 20);
+    searchLeft->setFont(buttonFont);
+    searchRight->setFont(buttonFont);
+    stationsBox->setFont(buttonFont);
+
+    QFont stationFont(currentFont.toString(), 20);
+    stationFont.setUnderline(true);
+    stationFont.setBold(true);
+    stationName->setFont(stationFont);
+    QFont rdsfont(currentFont.toString(), 14);
+
+    rdsData->setFont(rdsfont);
+    rdsData->setFont(rdsfont);
+
+}
+
+void Radio::saveCurrentFont()
+{
+    QSettings settings("Maemo", "qradio");
+    settings.setValue("currentFont", currentFont.toString());
+    settings.setValue("currentFontSize", currentFontSize);
+}
+
+void Radio::loadCurrentFont()
+{
+    QSettings settings("Maemo", "qradio");
+    QString currentFontString = settings.value("currentFont", "Digital-7").toString();
+    currentFontSize = settings.value("currentFontSize", 170).toInt();
+    currentFont = QFont(currentFontString, currentFontSize);
+    changeFont(currentFont, currentFontSize);
 }
