@@ -19,9 +19,12 @@ class Radio : public QWidget
 public:
      explicit Radio(QWidget *parent = 0);
     ~Radio();
-    int currentFreq;
+    double currentFreq;
     int currentSet;
     int currentIndex;
+    int currentFontSize;
+    QFont currentFont;
+    bool restart;
     QStringList stationsList;
     QStringList set1List;
     QStringList set2List;
@@ -30,8 +33,9 @@ public:
 
 private:
     QLabel* stationName;
+    QLabel* rdsData;
     QLabel* signal;
-    QLCDNumber *freq;
+    QLabel *freq;
     ClickableImage *leftImage;
     ClickableImage *rightImage;
     QPushButton* searchLeft;
@@ -65,6 +69,14 @@ public slots:
         void nextButtonClicked();
         void setLastIndex();
         void restartRadio();
+        void readRds();
+        void saveCurrentIndex();
+        void loadCurrentIndex();
+        QFont getFontType();
+        int getFontSize();
+        void changeFont(QFont, int);
+        void saveCurrentFont();
+        void loadCurrentFont();
 
 
 };
